Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1223)

Unified Diff: third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h

Issue 1780723002: Enable Emoji Fitzpatrick modifier sequences (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebased on renamed CharacterData file Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h
diff --git a/third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h b/third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h
index 0d7ad28f9eca27c63de1c6a733aa14eb0fbadd41..75cc46e133a14e3b06f36d48293a1b5266116f7a 100644
--- a/third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h
+++ b/third_party/WebKit/Source/platform/fonts/shaping/CachingWordShapeIterator.h
@@ -127,9 +127,9 @@ private:
bool hasAnyScript = !Character::isCommonOrInheritedScript(ch);
for (unsigned i = end; i < length; end = i) {
U16_NEXT(m_textRun.characters16(), i, length, ch);
// ZWJ check in order not to split Emoji ZWJ sequences.
if (U_GET_GC_MASK(ch) & (U_GC_M_MASK | U_GC_LM_MASK | U_GC_SK_MASK)
- || ch == zeroWidthJoinerCharacter)
+ || ch == zeroWidthJoinerCharacter || Character::isModifier(ch))
continue;
// Avoid delimiting COMMON/INHERITED alone, which makes harder to
// identify the script.
@@ -127,9 +127,9 @@ private:
for (unsigned i = end; i < length; end = i) {
U16_NEXT(m_textRun.characters16(), i, length, ch);
- // ZWJ check in order not to split Emoji ZWJ sequences.
+ // ZWJ and modifier check in order not to split those Emoji sequences.
if (U_GET_GC_MASK(ch) & (U_GC_M_MASK | U_GC_LM_MASK | U_GC_SK_MASK)

Powered by Google App Engine
This is Rietveld 408576698